# -*- makefile -*-
# Makefile for Microsoft Windows with Intel C++ Compiler

GENERATE_DLL=0
FAULT_TOLERANT=0

OBJS = class.obj compiler.obj database.obj hashtab.obj file.obj \
	sync.obj symtab.obj ttree.obj container.obj cursor.obj query.obj w32sock.obj \
	wwwapi.obj localcli.obj

CLI_OBJS = cli.obj w32sock.obj sync.obj repsock.obj 

INCS = fastdb.h stdtp.h class.h database.h cursor.h reference.h wwwapi.h \
	array.h file.h hashtab.h ttree.h container.h sync.h sync_w32.h config.h \
	query.h datetime.h harray.h timeseries.h exception.h

FASTDB_LIB = fastdb.lib 
CLI_LIB = cli.lib
FASTDB_DLL = fastdb.dll 
CLI_DLL = cli.dll

EXES = subsql.exe cgistub.exe forcerecovery.exe

EXAMPLES = guess.exe guess2.exe guess_std.exe testdb.exe testleak.exe testjoin.exe testddl.exe testperf.exe testsync.exe testconc.exe testiref.exe testtrav.exe testidx.exe bugdb.exe clidb.exe clitest.exe clitest2.exe localclitest.exe testraw.exe testconcur.exe testharr.exe

CC = icl

# DEFS macro is deprecatred, edit config.h file instead
DEFS = 

CFLAGS = -c -nologo -Zi -W3 -GX -MTd $(DEFS)
#CFLAGS = -c -nologo -Od -Zi -W3 -MTd -GX -DFASTDB_DEBUG=DEBUG_TRACE $(DEFS)
#CFLAGS = -c -Ox -G6 -nologo -Zi -W3 -GX -MT $(DEFS)

LD = $(CC)
LDFLAGS = -MTd -Zi -nologo
#LDFLAGS = -MT -Zi -nologo

#DLLFLAGS = -LD -nologo
DLLFLAGS = -LDd -Zi -nologo

AR = lib
ARFLAGS = 

STDLIBS = advapi32.lib

SOCKLIBS = wsock32.lib

!IF $(FAULT_TOLERANT)
DEFS = $(DEFS) -DREPLICATION_SUPPORT
STDLIBS = $(STDLIBS) $(SOCKLIBS)
!ENDIF


!IF $(GENERATE_DLL)
all: $(FASTDB_LIB) $(CLI_LIB) $(FASTDB_DLL) $(CLI_DLL) $(EXES) $(EXAMPLES)
DEFS = $(DEFS) -DFASTDB_DLL
!ELSE
all: $(FASTDB_LIB) $(CLI_LIB) $(EXES) $(EXAMPLES)
!ENDIF

class.obj: class.cpp compiler.h compiler.d symtab.h $(INCS)
	$(CC) $(CFLAGS) class.cpp

compiler.obj: compiler.cpp compiler.h compiler.d symtab.h $(INCS)
	$(CC) $(CFLAGS) compiler.cpp

query.obj: query.cpp compiler.h compiler.d symtab.h $(INCS)
	$(CC) $(CFLAGS) query.cpp

database.obj: database.cpp compiler.h compiler.d symtab.h $(INCS)
	$(CC) $(CFLAGS) database.cpp

localcli.obj: localcli.cpp compiler.h compiler.d symtab.h localcli.h $(INCS)
	$(CC) $(CFLAGS) localcli.cpp

cursor.obj: cursor.cpp compiler.h compiler.d $(INCS)
	$(CC) $(CFLAGS) cursor.cpp

hashtab.obj: hashtab.cpp $(INCS)
	$(CC) $(CFLAGS) hashtab.cpp

file.obj: file.cpp $(INCS)
	$(CC) $(CFLAGS) file.cpp

sync.obj: sync.cpp $(INCS)
	$(CC) $(CFLAGS) sync.cpp

symtab.obj: symtab.cpp symtab.h $(INCS)
	$(CC) $(CFLAGS) symtab.cpp

ttree.obj: ttree.cpp $(INCS)
	$(CC) $(CFLAGS) ttree.cpp

container.obj: container.cpp $(INCS)
	$(CC) $(CFLAGS) container.cpp

wwwapi.obj: wwwapi.cpp wwwapi.h stdtp.h sync.h sockio.h sync_w32.h config.h
	$(CC) $(CFLAGS) wwwapi.cpp

w32sock.obj: w32sock.cpp w32sock.h sockio.h stdtp.h
	$(CC) $(CFLAGS) w32sock.cpp

repsock.obj: repsock.cpp repsock.h sockio.h stdtp.h sync.h sync_w32.h config.h
	$(CC) $(CFLAGS) repsock.cpp

cli.obj: cli.cpp cli.h cliproto.h repsock.h sockio.h stdtp.h sync.h sync_w32.h config.h
	$(CC) $(CFLAGS) cli.cpp


fastdb.lib: $(OBJS)
	$(AR) $(ARFLAGS) /OUT:fastdb.lib $(OBJS)

fastdb.dll: $(OBJS)
	$(CC) $(DLLFLAGS) /Fefastdb.dll $(OBJS) $(STDLIBS) $(SOCKLIBS)

cli.lib: $(CLI_OBJS)
	$(AR) $(ARFLAGS) /OUT:cli.lib $(CLI_OBJS)

cli.dll: $(CLI_OBJS)
	$(CC) $(DLLFLAGS) /Fecli.dll $(CLI_OBJS) $(STDLIBS) $(SOCKLIBS)

subsql.obj: subsql.cpp compiler.h server.h compiler.d subsql.h symtab.h $(INCS)
	$(CC) $(CFLAGS) subsql.cpp

server.obj: server.cpp server.h compiler.h compiler.d subsql.h symtab.h $(INCS)
	$(CC) $(CFLAGS) server.cpp

subsql.exe: subsql.obj server.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) subsql.obj server.obj $(FASTDB_LIB) $(STDLIBS) $(SOCKLIBS)


clitest.obj: clitest.c cli.h
	$(CC) $(CFLAGS) clitest.c

clitest.exe: clitest.obj $(CLI_LIB)
	$(LD) $(LDFLAGS) clitest.obj $(CLI_LIB) $(STDLIBS) $(SOCKLIBS)

clitest2.obj: clitest2.c cli.h
	$(CC) $(CFLAGS) clitest2.c

clitest2.exe: clitest2.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) /Feclitest2.exe clitest2.obj $(FASTDB_LIB) $(STDLIBS)

localclitest.exe: clitest.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) /Felocalclitest.exe clitest.obj $(FASTDB_LIB) $(STDLIBS)

bugdb.obj: bugdb.cpp bugdb.h $(INCS)
	$(CC) $(CFLAGS) bugdb.cpp

bugdb.exe: bugdb.obj  $(FASTDB_LIB)
	$(LD) $(LDFLAGS) bugdb.obj $(FASTDB_LIB) $(STDLIBS) $(SOCKLIBS)


clidb.obj: clidb.cpp clidb.h $(INCS)
	$(CC) $(CFLAGS) clidb.cpp

clidb.exe: clidb.obj  $(FASTDB_LIB)
	$(LD) $(LDFLAGS) clidb.obj $(FASTDB_LIB) $(STDLIBS) $(SOCKLIBS)


cgistub.obj: cgistub.cpp stdtp.h sockio.h
	$(CC) $(CFLAGS) cgistub.cpp 

cgistub.exe: cgistub.obj
	$(LD) $(LDFLAGS) cgistub.obj $(FASTDB_LIB) $(STDLIBS) $(SOCKLIBS)


forcerecovery.obj: forcerecovery.cpp database.h
	$(CC) $(CFLAGS) forcerecovery.cpp 

forcerecovery.exe: forcerecovery.obj
	$(LD) $(LDFLAGS) forcerecovery.obj


guess.obj: guess.cpp $(INCS)
	$(CC) $(CFLAGS) guess.cpp 

guess.exe: guess.obj $(FASTDB_LIB)
	$(LD) -Feguess.exe $(LDFLAGS) guess.obj $(FASTDB_LIB) $(STDLIBS)

testharr.obj: testharr.cpp $(INCS)
	$(CC) $(CFLAGS) testharr.cpp 

testharr.exe: testharr.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) testharr.obj $(FASTDB_LIB) $(STDLIBS)

guess_std.obj: guess_std.cpp $(INCS)
	$(CC) $(CFLAGS) guess_std.cpp 

guess_std.exe: guess_std.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) guess_std.obj $(FASTDB_LIB) $(STDLIBS)

guess2.obj: guess2.cpp $(INCS)
	$(CC) $(CFLAGS) guess2.cpp 

guess2.exe: guess2.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) guess2.obj $(FASTDB_LIB) $(STDLIBS)

testdb.obj: testdb.cpp $(INCS)
	$(CC) $(CFLAGS) testdb.cpp 

testdb.exe: testdb.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) testdb.obj $(FASTDB_LIB) $(STDLIBS)

testraw.obj: testraw.cpp $(INCS)
	$(CC) $(CFLAGS) testraw.cpp 

testraw.exe: testraw.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) testraw.obj $(FASTDB_LIB) $(STDLIBS)

testconcur.obj: testconcur.cpp $(INCS)
	$(CC) $(CFLAGS) testconcur.cpp 

testconcur.exe: testconcur.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) testconcur.obj $(FASTDB_LIB) $(STDLIBS)

testleak.obj: testleak.cpp $(INCS)
	$(CC) $(CFLAGS) testleak.cpp 

testleak.exe: testleak.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) testleak.obj $(FASTDB_LIB) $(STDLIBS)

testjoin.obj: testjoin.cpp $(INCS)
	$(CC) $(CFLAGS) testjoin.cpp 

testjoin.exe: testjoin.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) testjoin.obj $(FASTDB_LIB) $(STDLIBS)

testddl.obj: testddl.cpp $(INCS)
	$(CC) $(CFLAGS) testddl.cpp 

testddl.exe: testddl.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) testddl.obj $(FASTDB_LIB) $(STDLIBS)

testperf.obj: testperf.cpp $(INCS)
	$(CC) $(CFLAGS) testperf.cpp 

testperf.exe: testperf.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) testperf.obj $(FASTDB_LIB) $(STDLIBS)

testidx.obj: testidx.cpp $(INCS)
	$(CC) $(CFLAGS) testidx.cpp 

testidx.exe: testidx.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) testidx.obj $(FASTDB_LIB) $(STDLIBS)

testsync.obj: testsync.cpp $(INCS)
	$(CC) $(CFLAGS) testsync.cpp 

testsync.exe: testsync.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) testsync.obj $(FASTDB_LIB) $(STDLIBS)

testconc.obj: testconc.cpp $(INCS)
	$(CC) $(CFLAGS) testconc.cpp 

testconc.exe: testconc.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) testconc.obj $(FASTDB_LIB) $(STDLIBS)

testiref.obj: testiref.cpp $(INCS)
	$(CC) $(CFLAGS) testiref.cpp 

testiref.exe: testiref.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) testiref.obj $(FASTDB_LIB) $(STDLIBS)

testtrav.obj: testtrav.cpp $(INCS)
	$(CC) $(CFLAGS) testtrav.cpp 

testtrav.exe: testtrav.obj $(FASTDB_LIB)
	$(LD) $(LDFLAGS) testtrav.obj $(FASTDB_LIB) $(STDLIBS)



cleanobj:
	-del *.odb,*.exp,*.obj,*.pch,*.pdb,*.ilk,*.dsp,*.dsw,*.ncb,*.opt

cleandbs:
	-del *.fdb

clean: cleanobj cleandbs
	-del *~,*.lib,*.dll,*.exe


zip: clean
	cd ..
	-del fastdb.zip
        zip -r fastdb.zip fastdb

copyzip: zip
	copy fastdb.zip d:


doxygen:
	doxygen doxygen.cfg